@@ -132,7 +132,7 @@ def slug_taxonomy_query(
 
     def result_preprocess_function(leaf_terms, terms, call_context):
         ctx = defaultdict(list)
-        for lt in leaf_terms.values():
+        for lt in terms.values():
             slug = lt.slug.split('/')
 
             if call_context.get('prefix'):
